@@ -235,7 +235,7 @@ class MainWindow(QMainWindow):
         if nodeid != self.actnode:
             self.actnode = nodeid
             node = self.nodes[nodeid]
-            self.nodelabel.setText('<b>Node</b> {}:{}'.format(node.host_num, node.node_num))
+            self.nodelabel.setText(f'<b>Node</b> {node.host_num}:{node.node_num}')
             self.nodetree.setCurrentItem(node, 0, QItemSelectionModel.SelectionFlag.ClearAndSelect)
 
     def nodesChanged(self, data):
@@ -268,7 +268,7 @@ class MainWindow(QMainWindow):
                 if node_id not in self.nodes:
                     # node_num = node_id[-2] * 256 + node_id[-1]
                     node = QTreeWidgetItem(host)
-                    node.setText(0, '{}:{} <init>'.format(host.host_num, node_num + 1))
+                    node.setText(0, f'{host.host_num}:{node_num + 1} <init>')
                     node.setText(1, '00:00:00')
                     node.node_id  = node_id
                     node.node_num = node_num + 1
@@ -306,7 +306,7 @@ class MainWindow(QMainWindow):
     def setNodeInfo(self, connid, time, scenname):
         node = self.nodes.get(connid)
         if node:
-            node.setText(0, '{}:{} <{}>'.format(node.host_num, node.node_num, scenname))
+            node.setText(0, f'{node.host_num}:{node.node_num} <{scenname}>')
             node.setText(1, time)
 
     @pyqtSlot(QTreeWidgetItem, int)
